# -*- coding: utf-8 -*-
# Part of smurf. See LICENSE file for full copyright and licensing details.

"""Project metadata

Information describing the project.
"""

# The package name, which is also the 'UNIX name' for the project.
package = 'smurf'
project = 'string morping, for smurfing from a string to another'

version = "2019.06.03"

description =project
authors = ['Erdal Yildiz']
authors_string = ', '.join(authors)
emails = ['erdalyildiz1974@gmail.com']
license = 'GPL-3.0'
copyright = '2019 ' + authors_string
url = 'https://github.com/e7dal/smurf'

